(set-background "level1.png")
(set-skin "skin.png")
(set-bonus-time 80000)
(load "../utils.scm")
(block-rect 32 50 5 1 "dark-brown")
(block-rect 320 50 5 1 "dark-brown")
(block-rect 32 68 5 1 "light-brown")
(block-rect 320 68 5 1 "light-brown")
(block-rect 32 86 5 1 "dark-brown")
(block-rect 320 86 5 1 "dark-brown")
(block-rect 32 104 5 1 "light-brown")
(block-rect 320 104 5 1 "light-brown")
(block-rect 32 122 5 1 "dark-brown")
(block-rect 320 122 5 1 "dark-brown")
(block-rect 32 140 5 1 "light-brown")
(block-rect 320 140 5 1 "light-brown")

